@@ -299,6 +299,8 @@ gok_modifier_mask_for_name (Display *display, char *modifier_name)
 		return SPI_KEYMASK_MOD3;
 	else if (!strcmp (modifier_name, "mod4"))
 		return SPI_KEYMASK_MOD4;
+	else if (!strcmp (modifier_name, "mod5"))
+		return SPI_KEYMASK_MOD5;
 	else
 		return SPI_KEYMASK_UNMODIFIED;
 }
