@@ -420,7 +420,7 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 
 /**
  *
- * Returns keycode for OUTPUT_KEYCODE keys, or -1.
+ * Returns keycode for OUTPUT_KEYCODE and OUTPUT_KEYSYM keys, or -1.
  **/
 int 
 gok_output_get_keycode (GokOutput *output)
@@ -428,6 +428,9 @@ gok_output_get_keycode (GokOutput *output)
     int keycode = -1;
     if (output && output->Type == OUTPUT_KEYCODE)
 	keycode = atoi (output->Name);
+    else if (output && output->Type == OUTPUT_KEYSYM)
+	keycode = XKeysymToKeycode (gok_main_display (), 
+				    XStringToKeysym (output->Name));
 
     return keycode;
 }
