@@ -67,7 +67,7 @@ gboolean gok_page_actions_initialize (GtkWidget* pWindowSettings)
 	
 	g_assert (pWindowSettings != NULL);
 	m_pWindowSettings = pWindowSettings;
-	m_pActionCurrent = NULL;
+	m_pActionCurrent = gok_action_get_first_action ();
 	m_bIgnoreChangeName = FALSE;
 	m_bChanged = TRUE;
 
@@ -75,20 +75,9 @@ gboolean gok_page_actions_initialize (GtkWidget* pWindowSettings)
 	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboActionNames");
 	g_assert (pComboBox != NULL);
 	
-	pAction = gok_action_get_first_action();
-	while (pAction != NULL)
-	{
-		items = g_list_append (items, pAction->pDisplayName);
-		pAction = pAction->pActionNext;
-	}
+	gok_page_actions_fill_combo_action_names();
 	
-	/* sort the action names */
-	items = g_list_sort (items, gok_settingsdialog_sort);
-	
-	gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
-	g_list_free (items);
-	
-	gok_page_actions_update_controls (m_pActionCurrent);
+	gok_page_actions_update_controls (gok_action_get_first_action ());
 
 	/* initialize the XInput device combobox */
 	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboInputDevice");
@@ -709,6 +698,7 @@ void gok_page_actions_action_changed (GtkEditable* pEditControl)
 	m_pActionCurrent = pAction;
 	
 	/* update the controls to reflect this action */
+
 	gok_page_actions_update_controls (pAction);
 }
 
@@ -1046,7 +1036,14 @@ void gok_page_actions_set_is_corepointer (gboolean bCorePointer)
 {
 	g_assert (m_pActionCurrent != NULL);
 	
-	if (m_ControlType ==  ACTION_TYPE_SWITCH)
+	/* Never override dwell action type (fixes bug 136756). 
+	NOTE: Currently the dwell action has a redundant free switch 1 
+	press action.  This is good for dwell users who can operate a switch 
+	sometimes. It might be best not to do this, and to allow aggregation 
+	of actions, or allow multiple actions to be specified for a single 
+	access method operation.
+	TODO: make dwell action press-ability less kludgy */
+	if ((m_ControlType ==  ACTION_TYPE_SWITCH) && (m_pActionCurrent->Type != ACTION_TYPE_DWELL))
 	{
 		if (bCorePointer)
 			m_pActionCurrent->Type = ACTION_TYPE_MOUSEBUTTON;
