@@ -27,10 +27,11 @@
 
 gboolean gok_repeat_getArmed(void);
 gboolean gok_repeat_getStarted(void);
-void gok_repeat_arm(void);
+void gok_repeat_arm(GokKey *pKey);
 void gok_repeat_stop(void);
 void gok_repeat_disarm(void);
+gboolean gok_repeat_toggle_armed (GokKey *key);
 gboolean gok_repeat_key(GokKey* pKey);
-
+void gok_repeat_drop_refs (GokKey *key);
 
 #endif /*__GOKREPEAT_H__*/
